@@ -5,6 +5,7 @@ pub mod code;
 pub mod theatre;
 pub mod novel;
 pub mod beamer;
+pub mod lachaise;
 
 use basic::*;
 use book::*;
@@ -12,4 +13,5 @@ use math::*;
 use code::*;
 use theatre::*;
 use novel::*;
-use beamer::*;
\ No newline at end of file
+use beamer::*;
+use lachaise::*;
\ No newline at end of file
